@@ -81,9 +81,9 @@ module Raven
         'sentry_version' => PROTOCOL_VERSION,
         'sentry_client' => USER_AGENT,
         'sentry_timestamp' => now,
-        'sentry_key' => configuration.public_key,
-        'sentry_secret' => configuration.secret_key
+        'sentry_key' => configuration.public_key
       }
+      fields['sentry_secret'] = configuration.secret_key unless configuration.secret_key.nil?
       'Sentry ' + fields.map { |key, value| "#{key}=#{value}" }.join(', ')
     end
 
