@@ -1,13 +1,7 @@
 require "spec_helper"
 
-describe "Rails Integration", :type => :request, :rails => true do
+RSpec.describe "Rails Integration", :type => :request, :rails => true do
   before(:all) do
-    require "rspec/rails"
-    require "raven/integrations/rack"
-    require "raven/integrations/rails"
-
-    Rails.logger = Logger.new(nil)
-    Rails.env = "production"
     TestApp.initialize!
   end
 
@@ -19,21 +13,35 @@ describe "Rails Integration", :type => :request, :rails => true do
     expect(TestApp.middleware).to include(Raven::Rack)
   end
 
+  it "doesn't do anything on a normal route" do
+    get "/"
+
+    expect(response.status).to eq(200)
+    expect(Raven.client.transport.events.size).to eq(0)
+  end
+
   it "should capture exceptions in production" do
     get "/exception"
+
     expect(response.status).to eq(500)
-    expect(Raven.client.transport.events.size).to eq(1)
+    event = JSON.parse!(Raven.client.transport.events.first[1])
+    expect(event["logentry"]["message"]).to eq("RuntimeError: An unhandled exception!")
   end
 
   it "should properly set the exception's URL" do
     get "/exception"
 
-    event = Raven.client.transport.events.first
-    event = JSON.parse!(event[1])
-
+    event = JSON.parse!(Raven.client.transport.events.first[1])
     expect(event['request']['url']).to eq("http://www.example.com/exception")
   end
 
+  it "sets transaction to ControllerName#method" do
+    get "/exception"
+
+    event = JSON.parse!(Raven.client.transport.events.first[1])
+    expect(event['transaction']).to eq("HelloController#exception")
+  end
+
   it "sets Raven.configuration.logger correctly" do
     expect(Raven.configuration.logger).to eq(Rails.logger)
   end
