@@ -20,6 +20,19 @@ end
 RSpec.configure do |config|
   config.mock_with(:rspec) { |mocks| mocks.verify_partial_doubles = true }
   config.raise_errors_for_deprecations!
+  config.disable_monkey_patching!
+  Kernel.srand config.seed
+end
+
+RSpec.shared_examples "Raven default capture behavior" do
+  it "captures exceptions" do
+    expect { block }.to raise_error(captured_class)
+
+    expect(Raven.client.transport.events.size).to eq(1)
+
+    event = JSON.parse!(Raven.client.transport.events.first[1])
+    expect(event["logentry"]["message"]).to eq("#{captured_class.name}: #{captured_message}")
+  end
 end
 
 def build_exception
