@@ -16,8 +16,6 @@ class TestApp < Rails::Application
 
   # Usually set for us in production.rb
   config.eager_load = true
-  config.cache_classes = true
-  config.serve_static_files = false
 
   routes.append do
     get "/exception", :to => "hello#exception"
@@ -37,8 +35,6 @@ class HelloController < ActionController::Base
   end
 
   def world
-    render :text => "Hello World!"
+    render :plain => "Hello World!"
   end
 end
-
-Rails.env = "production"
